@@ -1,12 +1,15 @@
 #include "groove.h"
 #if defined(Q_WS_MAEMO_5) || defined(Q_WS_HILDON)
 #include "qmaemo5rotator.h"
-#endif
 #include <QtDBus>
+#endif
+
 
 groove::groove(QWidget *parent) :
     QWidget(parent)
 {
+    //mpg = new mpgplayer();
+    //mpg->start();
     mBar = new QMenuBar();
     //mBar->addAction("test");
     sMethod = new QPushButton("Song:");
@@ -104,8 +107,11 @@ groove::groove(QWidget *parent) :
     connect(bBar,SIGNAL(addB()),this,SLOT(addSongPlaylist()));
     connect(bBar,SIGNAL(nextB()),player,SLOT(playNext()));
     connect(bBar,SIGNAL(pause()),this,SLOT(stop()));
+
     connect(bBar,SIGNAL(back()),player,SLOT(back()));
     bBar->setPlaybackProgress(100,100);
+    //pwindow = new pListWin(0);
+    //pwindow->show();
 
 }
 void groove::performSearch(QString s)
@@ -159,11 +165,15 @@ void groove::changeS( QAction * action)
     sMethod->setText(action->text());
     sMethod->setMaximumWidth(sMethod->sizeHint().rwidth());
 }
+
 void groove::showOthers()
 {
+#if defined(Q_WS_MAEMO_5) || defined(Q_WS_HILDON)
     QDBusConnection c = QDBusConnection::sessionBus();
     QDBusMessage m = QDBusMessage::createSignal("/", "com.nokia.hildon_desktop", "exit_app_view");
+
     c.send(m);
+#endif
 }
 
 void groove::play()
@@ -197,11 +207,13 @@ void groove::addSongPlaylist()
             pl->addSong(item);
         model->item(selected.first().row(),1)->setText("Added to Playlist");;
     }
+    //pwindow->updateList();
 }
 
 void groove::stop()
 {
     player->pause();
+    //mpg->pause();
 }
 void groove::moreB()
 {
