@@ -12,6 +12,8 @@
 #include "topbar.h"
 #include "vkb.h"
 #include "bottombar.h"
+//#include "mpgplayer.h"
+#include "plistwin.h"
 
 class groove : public QWidget
 {
@@ -35,6 +37,7 @@ private slots:
     void addSongPlaylist();
     void showOthers();
 private:
+    //mpgplayer *mpg;
     bottomBar *bBar;
     sPlayer *player;
     QMenuBar *mBar;
@@ -45,6 +48,7 @@ private:
     QPushButton *button;
     bool portrait;
     gscom *gs;
+    pListWin *pwindow;
 #if defined(Q_WS_MAEMO_5) || defined(Q_WS_HILDON)
     QMaemo5Rotator *rot;
 #endif
